@@ -2,9 +2,10 @@ import time
 from typing import Any, Dict, Union
 
 import jwt
-from datafet.custom_types import CustomError, JwtParam
 from ecdsa import SigningKey, VerifyingKey
 
+from ..custom_types import CustomError, JwtParam
+
 DEFAULT_ALGORITHM = "ES256"
 
 
@@ -34,7 +35,7 @@ def create_jwt(
             algorithm=algorithm,
         )
     except Exception as ex:
-        return CustomError("JWT Encoding Error", [f"{ex}"])
+        return CustomError(message="JWT Encoding Error", reasons=[f"{ex}"])
 
 
 def decode_jwt(
@@ -51,4 +52,4 @@ def decode_jwt(
             audience=audience,
         )
     except Exception as ex:
-        return CustomError("JWT Decoding Error", [f"{ex}"])
+        return CustomError(message="JWT Decoding Error", reasons=[f"{ex}"])
